"""
#============================================================================#
#                                                                            #
#          FILE: bed_lookup (python 3)                                       #
#        AUTHOR: Michael D Dacre, mike.dacre@gmail.com                       #
#  ORGANIZATION: Stanford University                                         #
#       LICENSE: MIT License, property of Stanford, use as you wish          #
#       CREATED: 2015-12-13 17:38                                            #
# Last modified: 2016-10-27 11:13                                            #
#                                                                            #
#         Usage: This project contains only a single user useful component:  #
#                BedFile. To use:                                            #
#                                                                            #
#                from bed_lookup import BedFile                              #
#                                                                            #
#============================================================================#
"""

__version__ = '1.1'

# Define max length to use dictionary
_max_len = 180000000  # In bytes, this is approximately 5 million lines
# Line length dictionary:
#   1 million: ~ 35500000
#   5 million: ~ 180000000
#  10 million: ~ 366000000
# 100 million: ~ 3660000000
#
# NOTE: All calculations are based on snp files, bed files with gene models
# containing multiple exons will have different byte sizes. However, such files
# will tend to be much smaller than the above cutoff anyway, so it should not
# make much difference.

from ._bed_lookup import BedFile

__all__ = ["BedFile", "_bed_lookup"]



"""
Setup Script for bed_sqlite
"""
from setuptools import setup, find_packages
from Cython.Build import cythonize
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='bed_lookup',
    version='1.1',
    description='Lookup a gene by coordinate from a bed',
    long_description=long_description,
    url='https://github.com/MikeDacre/python_bed_sqlite',
    author='Michael Dacre',
    author_email='mike.dacre@gmail.com',
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Science/Research',
        'Environment :: Console',
        'Operating System :: Unix',
        'Natural Language :: English',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    keywords='bed',

    install_requires=['cython'],
    ext_modules=cythonize("bed_lookup/*.pyx", language='c++'),
    scripts=['bin/bed_location_lookup'],
    packages=['bed_lookup']

)
